# bddjango

## wiki文档

- [wiki文档地址_内网](https://www.bodexiong.vip/mkdocs/)
- [wiki文档地址_外网](https://wiki-bddjango.readthedocs.io/zh/)


## 安装

```
pip install bddjango
```


## 相关链接

- [github地址](https://github.com/bode135/bddjango)
- [pypi项目地址](https://pypi.org/project/bddjango/)
- [查看当前最新版本号](https://pypi.org/search/?q=bddjango)



